==> vokoscreen_2.0.5~beta.orig.tar.gz: vokoscreen-2.0.5-beta/language/vokoscreen_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>邮寄最后一个视频</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>邮寄一个或多个选取的视频</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>邮寄</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>您会看到视频作为附件</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>选取一个或多个文件</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>没有窗口边框</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>窗口边框</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>装置忙碌中</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认值</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>编码器</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要录制鼠标</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>视频路径</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>开始录制时最小化 Vokoscreen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>寄送</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>录制时间</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>大小(KB)</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>录制屏幕大小</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>设定帧率</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>开启目录</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒计时</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>播放最后一个视频</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>寄送视频</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个装置</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>实际的帧率</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>装置 %1 忙碌中</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.0.16~beta.orig.tar.gz: vokoscreen-2.0.16-beta/language/vokoscreen_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>邮寄最后一个视频</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>邮寄一个或多个选取的视频</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>邮寄</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>您会看到视频作为附件</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>选取一个或多个文件</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>is busy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Noborder</source>
        <translation>没有窗口边框</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>窗口边框</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认值</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>编码器</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要录制鼠标</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>视频路径</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>开始录制时最小化 Vokoscreen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>寄送</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>录制时间</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>大小(KB)</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>录制屏幕大小</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>设定帧率</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>开启目录</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒计时</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>播放最后一个视频</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>寄送视频</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个装置</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>实际的帧率</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>装置 %1 忙碌中</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
